#ifndef NT2_INCLUDE_FUNCTIONS_LOGSPACE_SUB_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOGSPACE_SUB_HPP_INCLUDED

#include <nt2/exponential/include/functions/logspace_sub.hpp>

#endif
